/*
 * xrick/include/system.h
 *
 * This source code file is part of the xrick distribution, and as such is
 * copyrighted. Please read the README file in the root directory of the
 * distribution for information about copyrights, trademarks, license,
 * disclaimers, etc.
 */

#ifndef _SYSTEM_H
#define _SYSTEM_H

#define ENABLE_SOUND 1

#include "gp32.h"

/*
 * If compiling w/gcc, then we can use attributes. UNUSED(x) flags a
 * parameter or a variable as potentially being unused, so that gcc doesn't
 * complain about it.
 *
 * Note: from OpenAL code: Darwin OS cc is based on gcc and has __GNUC__
 * defined, yet does not support attributes. So in theory we should exclude
 * Darwin target here.
 */
#ifdef __GNUC__
#define UNUSED(x) x __attribute((unused))
#else
#define UNUSED(x) x
#endif

/* there are true at least on x86 platforms */
typedef unsigned char U8;         /*  8 bits unsigned */
typedef unsigned short int U16;   /* 16 bits unsigned */
typedef unsigned int U32;         /* 32 bits unsigned */
typedef signed char S8;           /*  8 bits signed   */
typedef signed short int S16;     /* 16 bits signed   */
typedef signed int S32;           /* 32 bits signed   */

/* this must be after typedefs because it relies on types defined above */
#include "rects.h"
#include "img.h"

/*
 * main section
 */
extern void sys_init(void);
extern void sys_shutdown(void);
extern void sys_panic(char *, ...);
extern void sys_printf(char *, ...);
extern U32 sys_gettime(void);
extern void sys_sleep(int);

/*
 * video section
 */
#define SYSVID_ZOOM 1
#define SYSVID_MAXZOOM 1
#define SYSVID_WIDTH 320
#define SYSVID_HEIGHT 200

extern int vid_page;
extern GPDRAWSURFACE gpDraw[2];

extern void sysvid_init(void);
extern void sysvid_shutdown(void);
extern void sysvid_update(rect_t *);
extern void sysvid_clear(void);
extern void sysvid_zoom(S8);
extern void sysvid_toggleFullscreen(void);
extern void sysvid_setGamePalette(void);
extern void sysvid_setPalette(img_color_t *, U16);

/*
 * events section
 */
extern void sysevt_poll(void);
extern void sysevt_wait(void);

/*
 * keyboard section
 */
extern int syskbd_up;
extern int syskbd_down;
extern int syskbd_left;
extern int syskbd_right;
extern int syskbd_pause;
extern int syskbd_end;
extern int syskbd_xtra;
extern int syskbd_fire;
extern int syskbd_fire2;
extern int syskbd_fire3;

/*
 * sound section
 */
#ifdef ENABLE_SOUND
typedef struct {
#ifdef DEBUG
  char *name;
#endif
  U8 *buf;
  U32 len;
} sound_t;

extern sound_t *WAV_WAA;
extern sound_t *WAV_BOMB;
extern sound_t *WAV_BULLET;
extern sound_t *WAV_WALK;
extern sound_t *WAV_JUMP;
extern sound_t *WAV_DING;
extern sound_t *WAV_BOMBSHHT;
extern sound_t *WAV_BONUS;
extern sound_t *WAV_SHHT;
extern sound_t *WAV_BOX;
extern sound_t *WAV_DDDING;

extern void syssnd_init(void);
extern void syssnd_shutdown(void);
extern void syssnd_vol(S8);
extern void syssnd_toggleMute(void);
extern S8 syssnd_play(sound_t *, S8);
extern void syssnd_pause(U8, U8);
extern void syssnd_stop(S8);
#endif

/*
 * args section
 */
extern int sysarg_args_period;
extern int sysarg_args_map;
extern int sysarg_args_submap;
extern int sysarg_args_fullscreen;
extern int sysarg_args_zoom;
#ifdef ENABLE_SOUND
extern int sysarg_args_nosound;
extern int sysarg_args_vol;
#endif

extern void sysarg_init(void);

/*
 * joystick section
 */
#ifdef ENABLE_JOYSTICK
extern void sysjoy_init(void);
extern void sysjoy_shutdown(void);
#endif


#endif

/* eof */


